<?php
/**
 * @file
 * Contains a RealmUIController.
 *
 * @copyright Copyright(c) 2013 Previous Next Pty Ltd
 * @license GPL v2 http://www.fsf.org/licensing/licenses/gpl.html
 * @author Chris Skene chris at previousnext dot com dot au
 */

namespace Drupal\realm\Admin;

/**
 * UI controller.
 */
class RealmUIController extends \EntityBundleableUIController {

  /**
   * Overrides hook_menu() defaults.
   *
   * Main reason for doing this is that
   * parent class hook_menu() is optimized for entity type administration.
   */
  public function hook_menu() {

    $items = array();
    $id_count = count(explode('/', $this->path));
    $wildcard = isset($this->entityInfo['admin ui']['menu wildcard']) ? $this->entityInfo['admin ui']['menu wildcard'] : '%' . $this->entityType;

    $items[$this->path] = array(
      'title' => 'Realms',
      'description' => 'Add edit and update realms.',
      'page callback' => 'system_admin_menu_block_page',
      'access arguments' => array('access administration pages'),
      'file path' => drupal_get_path('module', 'system'),
      'file' => 'system.admin.inc',
    );

    // Change the overview menu type for the list of realms.
    $items[$this->path]['type'] = MENU_LOCAL_TASK;

    // Change the add page menu to multiple types of entities.
    $items[$this->path . '/add'] = array(
      'title' => 'Add a realm',
      'description' => 'Add a new realm',
      'page callback' => 'realm_add_page',
      'access callback' => 'realm_access',
      'access arguments' => array('edit'),
      'type' => MENU_NORMAL_ITEM,
      'weight' => 20,
      'file' => 'realm.admin.inc',
      'file path' => drupal_get_path('module', $this->entityInfo['module']),
    );

    // Add menu items to add each different type of entity.
    foreach (realm_get_types() as $type) {
      $items[$this->path . '/add/' . $type->type] = array(
        'title' => 'Add ' . $type->label,
        'page callback' => 'realm_form_wrapper',
        'page arguments' => array(realm_create(array('realm_type' => $type->type))),
        'access callback' => 'realm_access',
        'access arguments' => array('edit', 'edit ' . $type->type),
        'file' => 'realm.admin.inc',
        'file path' => drupal_get_path('module', $this->entityInfo['module']),
      );
    }

    // Loading and editing realm entities.
    $items[$this->path . '/realm/' . $wildcard] = array(
      'page callback' => 'realm_form_wrapper',
      'page arguments' => array($id_count + 1),
      'access callback' => 'realm_access',
      'access arguments' => array('edit', $id_count + 1),
      'weight' => 0,
      'context' => MENU_CONTEXT_PAGE | MENU_CONTEXT_INLINE,
      'file' => 'realm.admin.inc',
      'file path' => drupal_get_path('module', $this->entityInfo['module']),
    );
    $items[$this->path . '/realm/' . $wildcard . '/edit'] = array(
      'title' => 'Edit',
      'type' => MENU_DEFAULT_LOCAL_TASK,
      'weight' => -10,
      'context' => MENU_CONTEXT_PAGE | MENU_CONTEXT_INLINE,
    );

    $items[$this->path . '/realm/' . $wildcard . '/delete'] = array(
      'title' => 'Delete',
      'page callback' => 'realm_delete_form_wrapper',
      'page arguments' => array($id_count + 1),
      'access callback' => 'realm_access',
      'access arguments' => array('edit', $id_count + 1),
      'type' => MENU_LOCAL_TASK,
      'context' => MENU_CONTEXT_INLINE,
      'weight' => 10,
      'file' => 'realm.admin.inc',
      'file path' => drupal_get_path('module', $this->entityInfo['module']),
    );

    // Menu item for viewing realms.
    $items['realm/' . $wildcard] = array(
      'title callback' => 'realm_page_title',
      'title arguments' => array(1),
      'page callback' => 'realm_page_view',
      'page arguments' => array(1),
      'access callback' => 'realm_access',
      'access arguments' => array('view', 1),
      'type' => MENU_CALLBACK,
    );

    return $items;
  }

  /**
   * Create the markup for the add Realm Entities page within the class.
   *
   * So it can easily be extended/overridden.
   */
  public function addPage() {

    $item = menu_get_item();
    $content = system_admin_menu_block($item);

    if (count($content) == 1) {
      $item = array_shift($content);
      drupal_goto($item['href']);
    }

    return theme('realm_add_list', array('content' => $content));
  }

}
