<?php

/**
 * @file
 * Providing extra functionality for the Realm UI via views.
 */


/**
 * Implements hook_views_data().
 */
function realm_views_data_alter(&$data) {
  $data['realms']['link_realm'] = array(
    'field' => array(
      'title' => t('Link'),
      'help' => t('Provide a link to the realm.'),
      'handler' => 'realm_handler_link_field',
    ),
  );
  $data['realms']['edit_realm'] = array(
    'field' => array(
      'title' => t('Edit Link'),
      'help' => t('Provide a link to the edit form for the realm.'),
      'handler' => 'realm_handler_edit_link_field',
    ),
  );
  $data['realms']['delete_realm'] = array(
    'field' => array(
      'title' => t('Delete Link'),
      'help' => t('Provide a link to delete the realm.'),
      'handler' => 'realm_handler_delete_link_field',
    ),
  );
  // This content of this field are decided based on the menu structure that
  // follows realms/realm/%realm_id/op
  $data['realms']['operations'] = array(
    'field' => array(
      'title' => t('Operations links'),
      'help' => t('Display all operations available for this realm.'),
      'handler' => 'realm_handler_realm_operations_field',
    ),
  );
}


/**
 * Implements hook_views_default_views().
 */
function realm_views_default_views() {
  $views = array();

  $view = new view();
  $view->name = 'realms';
  $view->description = 'A list of all realms';
  $view->tag = 'realms';
  $view->base_table = 'realms';
  $view->human_name = 'Realms';
  $view->core = 7;
  $view->api_version = '3.0';
  $view->disabled = FALSE; /* Edit this to true to make a default view disabled initially */

  /* Display: Master */
  $handler = $view->new_display('default', 'Master', 'default');
  $handler->display->display_options['title'] = 'Realms';
  $handler->display->display_options['use_more_always'] = FALSE;
  $handler->display->display_options['access']['type'] = 'perm';
  $handler->display->display_options['access']['perm'] = 'create any realm type';
  $handler->display->display_options['cache']['type'] = 'none';
  $handler->display->display_options['query']['type'] = 'views_query';
  $handler->display->display_options['exposed_form']['type'] = 'basic';
  $handler->display->display_options['pager']['type'] = 'full';
  $handler->display->display_options['pager']['options']['items_per_page'] = '20';
  $handler->display->display_options['pager']['options']['offset'] = '0';
  $handler->display->display_options['pager']['options']['id'] = '0';
  $handler->display->display_options['pager']['options']['quantity'] = '9';
  $handler->display->display_options['style_plugin'] = 'table';
  $handler->display->display_options['style_options']['columns'] = array(
    'name' => 'name',
    'realm_id' => 'realm_id',
  );
  $handler->display->display_options['style_options']['default'] = '-1';
  $handler->display->display_options['style_options']['info'] = array(
    'name' => array(
      'sortable' => 0,
      'default_sort_order' => 'asc',
      'align' => '',
      'separator' => '',
    ),
    'realm_id' => array(
      'sortable' => 0,
      'default_sort_order' => 'asc',
      'align' => '',
      'separator' => '',
    ),
  );
  /* Header: Global: Result summary */
  $handler->display->display_options['header']['result']['id'] = 'result';
  $handler->display->display_options['header']['result']['table'] = 'views';
  $handler->display->display_options['header']['result']['field'] = 'result';
  $handler->display->display_options['header']['result']['empty'] = TRUE;
  /* No results behavior: Global: Text area */
  $handler->display->display_options['empty']['area']['id'] = 'area';
  $handler->display->display_options['empty']['area']['table'] = 'views';
  $handler->display->display_options['empty']['area']['field'] = 'area';
  $handler->display->display_options['empty']['area']['label'] = 'Empty ';
  $handler->display->display_options['empty']['area']['content'] = 'No realms have been created yet';
  /* Field: Realm: Machine-readable name */
  $handler->display->display_options['fields']['name']['id'] = 'name';
  $handler->display->display_options['fields']['name']['table'] = 'realms';
  $handler->display->display_options['fields']['name']['field'] = 'name';
  /* Field: Realm: Realm_type */
  $handler->display->display_options['fields']['realm_type']['id'] = 'realm_type';
  $handler->display->display_options['fields']['realm_type']['table'] = 'realms';
  $handler->display->display_options['fields']['realm_type']['field'] = 'realm_type';
  $handler->display->display_options['fields']['realm_type']['label'] = 'Type';
  /* Field: Realm: Link */
  $handler->display->display_options['fields']['link_realm']['id'] = 'link_realm';
  $handler->display->display_options['fields']['link_realm']['table'] = 'realms';
  $handler->display->display_options['fields']['link_realm']['field'] = 'link_realm';
  $handler->display->display_options['fields']['link_realm']['label'] = 'View';
  /* Field: Realm: Operations links */
  $handler->display->display_options['fields']['operations']['id'] = 'operations';
  $handler->display->display_options['fields']['operations']['table'] = 'realms';
  $handler->display->display_options['fields']['operations']['field'] = 'operations';
  /* Sort criterion: Realm: Changed */
  $handler->display->display_options['sorts']['changed']['id'] = 'changed';
  $handler->display->display_options['sorts']['changed']['table'] = 'realms';
  $handler->display->display_options['sorts']['changed']['field'] = 'changed';
  $handler->display->display_options['sorts']['changed']['exposed'] = TRUE;
  $handler->display->display_options['sorts']['changed']['expose']['label'] = 'Changed';
  /* Sort criterion: Realm: Created */
  $handler->display->display_options['sorts']['created']['id'] = 'created';
  $handler->display->display_options['sorts']['created']['table'] = 'realms';
  $handler->display->display_options['sorts']['created']['field'] = 'created';
  $handler->display->display_options['sorts']['created']['exposed'] = TRUE;
  $handler->display->display_options['sorts']['created']['expose']['label'] = 'Created';
  /* Sort criterion: Realm: Machine-readable name */
  $handler->display->display_options['sorts']['name']['id'] = 'name';
  $handler->display->display_options['sorts']['name']['table'] = 'realms';
  $handler->display->display_options['sorts']['name']['field'] = 'name';
  $handler->display->display_options['sorts']['name']['exposed'] = TRUE;
  $handler->display->display_options['sorts']['name']['expose']['label'] = 'Name';

  /* Display: Page */
  $handler = $view->new_display('page', 'Page', 'realms_admin_page');
  $handler->display->display_options['path'] = 'admin/content/realms/list';
  $handler->display->display_options['menu']['type'] = 'default tab';
  $handler->display->display_options['menu']['title'] = 'List';
  $handler->display->display_options['menu']['weight'] = '-10';
  $handler->display->display_options['tab_options']['type'] = 'tab';
  $handler->display->display_options['tab_options']['title'] = 'Realms';
  $handler->display->display_options['tab_options']['description'] = 'Manage realms';
  $handler->display->display_options['tab_options']['weight'] = '0';
  $handler->display->display_options['tab_options']['name'] = 'management';

  $views[] = $view;
  return $views;

}
