<?php

/**
 * @file
 * Contains a Views field handler to take care of displaying links to entities
 * as fields.
 */

/**
 * Class realm_handler_link_field
 */
class realm_handler_link_field extends views_handler_field {

  /**
   * Constructor.
   */
  public function construct() {
    parent::construct();

    $this->additional_fields['realm_id'] = 'realm_id';
    $this->additional_fields['realm_type'] = 'realm_type';
  }

  /**
   * Option definitions.
   */
  public function option_definition() {
    $options = parent::option_definition();

    $options['text'] = array('default' => '', 'translatable' => TRUE);

    return $options;
  }

  /**
   * Options form.
   */
  public function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['text'] = array(
      '#type' => 'textfield',
      '#title' => t('Text to display'),
      '#default_value' => $this->options['text'],
    );
  }

  /**
   * Query callback.
   */
  public function query() {
    $this->ensure_my_table();
    $this->add_additional_fields();
  }

  /**
   * Render callback.
   */
  public function render($values) {
    $text = !empty($this->options['text']) ? $this->options['text'] : t('view');
    $realm_id = $values->{$this->aliases['realm_id']};

    return l($text, 'realm/' . $realm_id);
  }
}
